@@ -4,10 +4,10 @@ use strict;
 use warnings;
 
 
-our $VERSION = 'v0.205.0';
+our $VERSION = 'v0.206.0';
 
 
-use Role::Declare -lax;
+use Role::Declare::Should;
 
 use OpenTracing::Types qw/SpanContext/;
 use Time::HiRes qw/time/;
