@@ -5,10 +5,10 @@ use strict;
 use warnings;
 
 
-our $VERSION = 'v0.205.0';
+our $VERSION = 'v0.206.0';
 
 
-use Role::Declare -lax; # so missing named parameters default to undef
+use Role::Declare::Should;
 
 use OpenTracing::Types qw/ContextReference Scope ScopeManager Span SpanContext/;
 use Types::Standard qw/ArrayRef Bool Dict HashRef Maybe Object Str/;
